Crate kcr_cloudfront_services_k8s_aws

Crate kcr_cloudfront_services_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the cloudfront.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

cloudfront.services.k8s.aws/v1alpha1

  • CachePolicy
  • Distribution
  • Function
  • OriginRequestPolicy
  • ResponseHeadersPolicy

Modules

v1alpha1